==> schlix-cms-v2.1.8-7.zip: schlix/system/macros/insertblockbyposition/insertblockbyposition.class.php <==
<?php
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC, Inc.
// http://www.schlix.com
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
namespace Macro;


class insertblockbyposition extends \SCHLIX\cmsMacro
{
    

    /**
     * Reaplces {insertblockbyposition [block_category]} with output
     * @global \App\Blocks $Blocks
     * @param string $text
     * @return string
     */
    private function processText($text)
    {
            global $Blocks;

            $regex = '/{insertblockbyposition\s*.*?}/i';
            
            preg_match_all( $regex, $text, $matches );
            $references = $matches[0];
            $count = ___c($references);
            if ( $count > 0 ) 
            {
                    for ($i = 0; $i < $count; $i++)
                    {
                            $reference = $references[$i];
                            // find the block position
                            $blockposition_to_load = trim(str_replace('}','',str_replace( '{', '', str_replace('insertblockbyposition', '', $reference) )));
                            // display block position
                            start_output_buffer();
                            $Blocks->displayBlockByCategoryNameRerun($blockposition_to_load);
                            $block_output = end_output_buffer();
                            // replace references with output
                          
                            $text = str_replace($reference,$block_output,$text);
                            
                    }

            }
            return $text;

    }
    //----------------------------------------------------------------------//
    /*
     * Run the macro
     * @global type $HTMLHeader
     * @param array|string $data
     * @param object $caller_object
     * @param string $caller_function
     * @param array $extra_info
     * @return string
     */
    public function Run(&$data, $caller_object, $caller_function, $extra_info = NULL) {
        
        if (is_array($data)) // don't enable it for block (string)
        {
            if (array_key_exists('summary', $data))
                $data['summary'] = $this->processText ($data['summary']);
            if (array_key_exists('description', $data))
                $data['description'] = $this->processText ($data['description']);            
        }
    }     
}
?>

==> schlix-cms-v2.2.7-1.zip: schlix/system/macros/insertblockbyposition/insertblockbyposition.class.php <==
<?php
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC, Inc.
// http://www.schlix.com
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
namespace Macro;


class insertblockbyposition extends \SCHLIX\cmsMacro
{
    

    /**
     * Reaplces {insertblockbyposition [block_category]} with output
     * @global \App\Core_BlockManager $Blocks
     * @param string $text
     * @return string
     */
    private function processText($text)
    {
            global $Blocks;

            $regex = '/{insertblockbyposition\s*.*?}/i';
            
            preg_match_all( $regex, $text, $matches );
            $references = $matches[0];
            $count = ___c($references);
            if ( $count > 0 ) 
            {
                    for ($i = 0; $i < $count; $i++)
                    {
                            $reference = $references[$i];
                            // find the block position
                            $blockposition_to_load = trim(str_replace('}','',str_replace( '{', '', str_replace('insertblockbyposition', '', $reference) )));
                            // display block position
                            start_output_buffer();
                            $Blocks->displayBlockByCategoryNameRerun($blockposition_to_load);
                            $block_output = end_output_buffer();                            
                            // replace references with output
                          
                            $text = str_replace($reference,$block_output,$text);
                            
                    }

            }
            return $text;

    }
    //----------------------------------------------------------------------//
    /*
     * Run the macro
     * @global type $HTMLHeader
     * @param array|string $data
     * @param object $caller_object
     * @param string $caller_function
     * @param array $extra_info
     * @return string
     */
    public function Run(&$data, $caller_object, $caller_function, $extra_info = NULL) {
        
        if (is_array($data)) // don't enable it for block (string)
        {
            if (array_key_exists('summary', $data))
                $data['summary'] = $this->processText ($data['summary']);
            if (array_key_exists('description', $data))
                $data['description'] = $this->processText ($data['description']);            
        }
    }     
}
